var global = Function("return this;")();
/*!
  * Ender: open module JavaScript framework (client-lib)
  * copyright Dustin Diaz & Jacob Thornton 2011 (@ded @fat)
  * http://ender.no.de
  * License MIT
  */
!function (context) {

  // a global object for node.js module compatiblity
  // ============================================

  context['global'] = context

  // Implements simple module system
  // losely based on CommonJS Modules spec v1.1.1
  // ============================================

  var modules = {}
    , old = context.$

  function require (identifier) {
    // modules can be required from ender's build system, or found on the window
    var module = modules[identifier] || window[identifier]
    if (!module) throw new Error("Requested module '" + identifier + "' has not been defined.")
    return module
  }

  function provide (name, what) {
    return (modules[name] = what)
  }

  context['provide'] = provide
  context['require'] = require

  function aug(o, o2) {
    for (var k in o2) k != 'noConflict' && k != '_VERSION' && (o[k] = o2[k])
    return o
  }

  function boosh(s, r, els) {
    // string || node || nodelist || window
    if (typeof s == 'string' || s.nodeName || (s.length && 'item' in s) || s == window) {
      els = ender._select(s, r)
      els.selector = s
    } else els = isFinite(s.length) ? s : [s]
    return aug(els, boosh)
  }

  function ender(s, r) {
    return boosh(s, r)
  }

  aug(ender, {
      _VERSION: '0.3.6'
    , fn: boosh // for easy compat to jQuery plugins
    , ender: function (o, chain) {
        aug(chain ? boosh : ender, o)
      }
    , _select: function (s, r) {
        return (r || document).querySelectorAll(s)
      }
  })

  aug(boosh, {
    forEach: function (fn, scope, i) {
      // opt out of native forEach so we can intentionally call our own scope
      // defaulting to the current item and be able to return self
      for (i = 0, l = this.length; i < l; ++i) i in this && fn.call(scope || this[i], this[i], i, this)
      // return self for chaining
      return this
    },
    $: ender // handy reference to self
  })

  ender.noConflict = function () {
    context.$ = old
    return this
  }

  if (typeof module !== 'undefined' && module.exports) module.exports = ender
  // use subscript notation as extern for Closure compilation
  context['ender'] = context['$'] = context['ender'] || ender

}(this);
// pakmanager:nhx.js
(function (context) {
  
  var module = { exports: {} }, exports = module.exports
    , $ = require("ender")
    ;
  
  /**
     * NHX format parser in JavaScript.
     *
     * Copyright (c) Zorji 2014.
     *
     * Permission is hereby granted, free of charge, to any person obtaining a copy
     * of this software and associated documentation files (the "Software"), to deal
     * in the Software without restriction, including without limitation the rights
     * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
     * copies of the Software, and to permit persons to whom the Software is
     * furnished to do so, subject to the following conditions:
     *
     * The above copyright notice and this permission notice shall be included in
     * all copies or substantial portions of the Software.
     *
     * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
     * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
     * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
     * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
     * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
     * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
     * THE SOFTWARE.
     *
     * Example tree (from http://en.wikipedia.org/wiki/Newick_format):
     *
     * +--0.1--A
     * F-----0.2-----B            +-------0.3----C
     * +------------------0.5-----E
     *                            +---------0.4------D
     *
     * Newick format:
     * (A:0.1,B:0.2,(C:0.3,D:0.4)E:0.5)F;
     *
     * Converted to JSON:
     * {
     *   name: "F",
     *   branchset: [
     *     {name: "A", length: 0.1},
     *     {name: "B", length: 0.2},
     *     {
     *       name: "E",
     *       length: 0.5,
     *       branchset: [
     *         {name: "C", length: 0.3},
     *         {name: "D", length: 0.4}
     *       ]
     *     }
     *   ]
     * }
     *
     * ---------------------------------------------------------------------------------------
     * NHX (from http://goby.compbio.cs.cmu.edu/Notung/2.6documentation/Manual-2.6.master014.html)
     *
     * NHX File Format is based on the Newick file format, but embeds additional
     * information about each node in the tree in the comment fields, as follows:
     *
     * [&&NHX:TagID1=value1:TagID2=value2]
     *
     * where TagID1 and TagID2 can specify bootstrap values, species labels, or
     * duplication information. This example has two tags, but NHX comments can
     * have one or more tags. Trees saved in NHX file format include information
     * produced by a reconciliation, including duplications and species labels, but
     * do not record any visual annotations made in Notung. Nor do they record the
     * species tree with which the gene tree was reconciled.
     *
     * NOTE: The NHX format is case-sensitive.
     * More information about NHX format, including a complete list of tags used
     * in comment fields, can be obtained at:
     *
     * http://www.genetics.wustl.edu/eddy/forester/NHX.html.
     *
     * NHX format:
     * (A:0.1[&&NHX:gn=10],B:0.2[&&NHX:gn=10],(C:0.3[&&NHX:gn=10],D:0.4[&&NHX:gn=10])E:0.5[&&NHX:gn=10])F[&&NHX:gn=10];
     *
     * Converted to JSON:
     * {
     *   name: "F",
     *   branchset: [
     *     {name: "A", length: 0.1, gn: '10'},
     *     {name: "B", length: 0.2, gn: '10'},
     *     {
     *       name: "E",
     *       length: 0.5,
     *       branchset: [
     *         {name: "C", length: 0.3, gn: '10'},
     *         {name: "D", length: 0.4, gn: '10'}
     *       ],
     *       gn: '10'
     *     }
     *   ]
     * }
     *
     */
    (function (exports) {
        exports.parse = function (str) {
    
            function tokenize(str) {
                var current = {
                    branchset: []
                };
                var begin = 0;
                var onAttr = false;
                var last = null;
                for (var i = 0; i < str.length; i++) {
                    var char = str[i];
                    switch (char) {
                        case '(':
                            var parent = current;
                            current = {
                                branchset: []
                            };
                            parent.branchset.push(current);
                            current.parent = parent;
                            begin = i + 1;
                            break;
                        case ')':
                            last = current;
                            current = current.parent;
                            begin = i + 1;
                            break;
                        case ',':
                            if (!onAttr) {
                                var val = {
                                    text: str.substr(begin, i - begin)
                                };
                                var bracketEndPos = str.lastIndexOf(')', begin);
                                var bracketBeginPos = str.lastIndexOf('(', begin);
                                var commaPos = str.lastIndexOf(',', begin);
                                if (Math.max(bracketEndPos, bracketBeginPos, commaPos) == bracketEndPos && bracketEndPos != -1) {
                                    last.text = val.text;
                                } else {
                                    current.branchset.push(val);
                                }
    
                                begin = i + 1;
                            }
                            break;
                        case '[':
                            onAttr = true;
                            break;
                        case ']':
                            onAttr = false;
                    }
                }
    
                return current;
            }
    
            /**
             * Deletes the parent attribute recursively which is only needed in tokenize stage
             *
             * @see tokenize
             * @param {Object} node
             * @returns {Object}
             */
            function deleteParentAttr(node) {
                if (node.hasOwnProperty('branchset')) {
                    node.branchset.forEach(deleteParentAttr);
                    delete node.parent;
                }
                return node;
            }
    
            /**
             * input:
             *   A:0.1
             * output:
             *   { name: 'A', length: 0.1 }
             *
             * input:
             *   A
             * output:
             *   { name: 'A', length: 0 }
             *
             * input:
             *  (empty string)
             * output:
             *   { name: '', length: 0 }
             *
             * @param {Object} node
             * @param {string} str
             */
            function setNameAndLength(node, str) {
                if (str.indexOf(':') != -1) {
                    var parts = str.split(':');
                    node.name = parts[0];
                    node.length = parseFloat(parts[1]);
                }
                else if (str.length) {
                    node.name = str;
                    node.length = 0;
                }
                else {
                    node.name = '';
                    node.length = 0;
                }
            }
    
            /**
             * input:
             *   gn=0.2948622:b=6, 7, 10
             * output:
             *   { gn: '0.2948622', b: '6, 7, 10' }
             *
             * @param {Object} node
             * @param {string} text
             */
            function setNhxAttrs(node, text) {
                if (text.length == 0) return;
                foreach(text.split(':'), function (kv) {
                    kv = kv.split('=');
                    node[kv[0]] = kv[1];
                });
            }
    
            /**
             * before:
             *   { text: A:0.1[&&NHX:gn=0.2948622:b=6, 7, 10] }
             * after:
             *   { name: 'A', length: 0.1, gn: '0.2948622', b: '6, 7, 10' }
             *
             * @param {Object} node
             * @returns {Object}
             */
            function translateNode(node) {
                if (node.hasOwnProperty('branchset')) {
                    foreach(node.branchset, translateNode);
                }
                if (node.hasOwnProperty('text')) {
                    var text = node.text.replace(/]$/g, '');
                    delete node.text;
                    var hasNhx = text.indexOf('[&&NHX:') != -1;
                    if (hasNhx) {
                        var parts = text.split('[&&NHX:');
                        setNameAndLength(node, parts[0]);
                        setNhxAttrs(node, parts[1]);
                    }
                    else {
                        setNameAndLength(node, text);
                    }
                }
    
                return node;
            }
    
            function foreach(collection, callback) {
                for (var i = 0; i < collection.length; i++) {
                    callback(collection[i]);
                }
            }
    
            /**
             * Appends a trailing comma on every array item to make parsing a bit easier
             *
             * input:
             *   (A:0.1,B:0.2,(C:0.3,D:0.4)E:0.5)F;
             * output:
             *   (A:0.1,B:0.2,(C:0.3,D:0.4,)E:0.5,)F;
             *
             * @param {string} text
             * @returns {string}
             */
            function appendComma(text) {
                return text.replace(/\)/g, ',)');
            }
    
            /**
             * '(A:0.1[&&NHX:gn=10],B:0.2[&&NHX:gn=10],(C:0.3[&&NHX:gn=10],D:0.4[&&NHX:gn=10])E:0.5[&&NHX:gn=10])F[&&NHX:gn=10];'
             */
            var tmp = str;
            /**
             * '(A:0.1[&&NHX:gn=10],B:0.2[&&NHX:gn=10],(C:0.3[&&NHX:gn=10],D:0.4[&&NHX:gn=10],)E:0.5[&&NHX:gn=10],)F[&&NHX:gn=10];'
             */
            tmp = appendComma(tmp);
            /**
             * { children:
             *    [ { children:
             *         [ { text: 'A:0.1[&&NHX:gn=10]' },
             *           { text: 'B:0.2[&&NHX:gn=10]' },
             *           { children:
             *              [ { text: 'C:0.3[&&NHX:gn=10]' },
             *                { text: 'D:0.4[&&NHX:gn=10]' } ],
             *             parent: [Circular],
             *             text: 'E:0.5[&&NHX:gn=10]' } ],
             *        parent: [Circular] } ] }
             */
            tmp = tokenize(tmp);
            /**
             * { children:
             *    [ { children:
             *         [ { text: 'A:0.1[&&NHX:gn=10]' },
             *           { text: 'B:0.2[&&NHX:gn=10]' },
             *           { children:
             *              [ { text: 'C:0.3[&&NHX:gn=10]' },
             *                { text: 'D:0.4[&&NHX:gn=10]' } ],
             *             text: 'E:0.5[&&NHX:gn=10]' } ] } ] }
             */
            tmp = deleteParentAttr(tmp);
            /**
             * { children:
             *    [ { children:
             *         [ { name: 'A', length: 0.1, gn: '10' },
             *           { name: 'B', length: 0.2, gn: '10' },
             *           { children:
             *              [ { name: 'C', length: 0.3, gn: '10' },
             *                { name: 'D', length: 0.4, gn: '10' } ],
             *             name: 'E',
             *             length: 0.5,
             *             gn: '10' } ] } ] }
             */
            tmp = translateNode(tmp);
    
            return tmp;
        };
    })(
        typeof exports !== 'undefined' ? exports : this.NHX = {}
    );
    
  provide("nhx.js", module.exports);
}(global));